@@ -1,13 +1,10 @@
+# -*- coding: utf-8 -*-
 #
 # dcolumn/common/model_mixins.py
 #
 
 """
 Mixins used in Django models.
-
-by: Carl J. Nobile
-
-email: carl.nobile@gmail.com
 """
 __docformat__ = "restructuredtext en"
 
@@ -18,12 +15,12 @@ from dateutil.tz import tzutc
 
 from django.db import models
 from django.db.models import Q
-from django.contrib.auth.models import User
 from django.utils.translation import ugettext_lazy as _
+from django.conf import settings
 
 from dcolumn.common import ChoiceManagerImplementation
 
-log = logging.getLogger('dcolumn.models')
+log = logging.getLogger('dcolumns.common.model_mixins')
 
 
 #
@@ -34,15 +31,16 @@ class UserModelMixin(models.Model):
     Abstract model mixin used in the model classes to provide user and
     creator fields.
     """
-
     updater = models.ForeignKey(
-        User, verbose_name=_("Updater"), db_index=True, editable=False,
+        settings.AUTH_USER_MODEL, on_delete=models.CASCADE,
+        verbose_name=_("Updater"), editable=False,
         related_name="%(app_label)s_%(class)s_updater_related",
         help_text=_("The last user to update this record."))
     creator = models.ForeignKey(
-        User, verbose_name=_("Creator"), db_index=True, editable=False,
+        settings.AUTH_USER_MODEL, on_delete=models.CASCADE,
+        verbose_name=_("Creator"), editable=False,
         related_name="%(app_label)s_%(class)s_creator_related",
-        help_text=_("The user  who created this record."))
+        help_text=_("The user who created this record."))
 
     class Meta:
         abstract = True
@@ -50,22 +48,41 @@ class UserModelMixin(models.Model):
     def save(self, *args, **kwargs):
         """
         Save is here to assure that save is executed throughout the MRO.
+
+        :param args: Positional arguments.
+        :param kwargs: Keyword arguments.
         """
         super(UserModelMixin, self).save(*args, **kwargs)
 
-    def _updater_producer(self):
+    def updater_producer(self):
         """
-        Primary use is in the admin class to supply the user's full name.
-        """
-        return self.updater.get_full_name()
-    _updater_producer.short_description = _("Updater")
+        Primary use is in an admin class to supply the updater's full name if
+        available else the username.
 
-    def _creator_producer(self):
+        :rtype: String of updater's full name.
         """
-        Primary use is in the admin class to supply the creator's full name.
+        result = self.updater.get_full_name()
+
+        if not result:
+            result = self.updater.username
+
+        return result
+    updater_producer.short_description = _("Updater")
+
+    def creator_producer(self):
         """
-        return self.creator.get_full_name()
-    _creator_producer.short_description = _("Creator")
+        Primary use is in an admin class to supply the creator's full name if
+        available else the username.
+
+        :rtype: String of creator's full name.
+        """
+        result = self.creator.get_full_name()
+
+        if not result:
+            result = self.creator.username
+
+        return result
+    creator_producer.short_description = _("Creator")
 
 
 #
@@ -76,7 +93,6 @@ class TimeModelMixin(models.Model):
     Abstract model mixin used in the model classes to supply created and
     updated fields.
     """
-
     created = models.DateTimeField(
         verbose_name=_("Date Created"),
         help_text=_("The date and time of creation."))
@@ -89,12 +105,19 @@ class TimeModelMixin(models.Model):
 
     def save(self, *args, **kwargs):
         """
-        Permit the disabling of the created and updated date times.
+        Understands two keyword arguments, ``disable_created`` and
+        ``disable_updated``. These arguments are used to optionally turn off
+        the updating of the ``created`` and ``updated`` fields on the model.
+        This can be used when migrating data into a model that already has
+        these fields set so the original date ad times can be kept.
+
+        :param args: Positional arguments.
+        :param kwargs: Keyword arguments.
         """
-        if not kwargs.pop(u'disable_created', False) and self.created is None:
+        if not kwargs.pop('disable_created', False) and self.created is None:
             self.created = datetime.now(tzutc())
 
-        if not kwargs.pop(u'disable_updated', False):
+        if not kwargs.pop('disable_updated', False):
             self.updated = datetime.now(tzutc())
 
         log.debug("kwargs: %s, created: %s, updated: %s",
@@ -114,10 +137,11 @@ class StatusModelManagerMixin(models.Manager):
         """
         Return as default only active database objects.
 
-        :Parameters:
-          active : `bool`
-            If `True` return only active records else if `False` return
-            non-active records. If `None` return all records.
+        :param active: If ``True`` return only active records else if ``False``
+                       return non-active records. If ``None`` return all
+                       records.
+        :type active: bool
+        :rtype: Django query results.
         """
         query = []
 
@@ -142,32 +166,27 @@ class StatusModelMixin(models.Model):
     def save(self, *args, **kwargs):
         """
         Save is here to assure that save is executed throughout the MRO.
+
+        :param args: Positional arguments.
+        :param kwargs: Keyword arguments.
         """
         super(StatusModelMixin, self).save(*args, **kwargs)
 
 
 #
-# BaseChoiceModelManager
+# ValidateOnSaveMixin
 #
-class BaseChoiceModelManager(models.Manager, ChoiceManagerImplementation):
+class ValidateOnSaveMixin(models.Model):
 
-    def get_value_by_pk(self, pk, field=None):
-        value = u''
+    class Meta:
+        abstract = True
 
-        if int(pk) != 0:
-            try:
-                obj = self.get(pk=pk)
-                value = getattr(obj, field)
-            except self.model.DoesNotExist as e:
-                log.error("Access to PK %s failed, %s", pk, e)
+    def save(self, *args, **kwargs):
+        """
+        Execute ``full_clean``.
 
-        return value
-
-    def get_choices(self, field, comment=True):
-        choices = [(obj.pk, getattr(obj, field)) for obj in self.all()]
-
-        if comment:
-            choices.insert(
-                0, (0, _("Please choose a {}".format(self.model.__name__))))
-
-        return choices
+        :param args: Positional arguments.
+        :param kwargs: Keyword arguments.
+        """
+        self.full_clean()
+        super(ValidateOnSaveMixin, self).save(*args, **kwargs)
